@@ -9,7 +9,7 @@
     $delete       = optional_param('delete', 0, PARAM_INT);
     $confirm      = optional_param('confirm', '', PARAM_ALPHANUM);   //md5 confirmation hash
     $confirmuser  = optional_param('confirmuser', 0, PARAM_INT);
-    $sort         = optional_param('sort', 'name', PARAM_ALPHANUM);
+    $sort         = optional_param('sort', 'name', PARAM_ALPHANUMEXT);
     $dir          = optional_param('dir', 'ASC', PARAM_ALPHA);
     $page         = optional_param('page', 0, PARAM_INT);
     $perpage      = optional_param('perpage', 30, PARAM_INT);        // how many per page
@@ -27,7 +27,7 @@
     $site = get_site();
 
     if (!has_capability('moodle/user:update', $sitecontext) and !has_capability('moodle/user:delete', $sitecontext)) {
-        print_error('nopermissions', 'error', '', 'edit/delete users');
+        throw new \moodle_exception('nopermissions', 'error', '', 'edit/delete users');
     }
 
     $stredit   = get_string('edit');
@@ -42,12 +42,15 @@
 
     $returnurl = new moodle_url('/admin/user.php', array('sort' => $sort, 'dir' => $dir, 'perpage' => $perpage, 'page'=>$page));
 
+    $PAGE->set_primary_active_tab('siteadminnode');
+    $PAGE->navbar->add(get_string('userlist', 'admin'), $PAGE->url);
+
     // The $user variable is also used outside of these if statements.
     $user = null;
     if ($confirmuser and confirm_sesskey()) {
         require_capability('moodle/user:update', $sitecontext);
         if (!$user = $DB->get_record('user', array('id'=>$confirmuser, 'mnethostid'=>$CFG->mnet_localhost_id))) {
-            print_error('nousers');
+            throw new \moodle_exception('nousers');
         }
 
         $auth = get_auth_plugin($user->auth);
@@ -63,12 +66,12 @@
 
     } else if ($resendemail && confirm_sesskey()) {
         if (!$user = $DB->get_record('user', ['id' => $resendemail, 'mnethostid' => $CFG->mnet_localhost_id, 'deleted' => 0])) {
-            print_error('nousers');
+            throw new \moodle_exception('nousers');
         }
 
         // Prevent spamming users who are already confirmed.
         if ($user->confirmed) {
-            print_error('alreadyconfirmed');
+            throw new \moodle_exception('alreadyconfirmed', 'moodle');
         }
 
         $returnmsg = get_string('emailconfirmsentsuccess');
@@ -85,10 +88,10 @@
         $user = $DB->get_record('user', array('id'=>$delete, 'mnethostid'=>$CFG->mnet_localhost_id), '*', MUST_EXIST);
 
         if ($user->deleted) {
-            print_error('usernotdeleteddeleted', 'error');
+            throw new \moodle_exception('usernotdeleteddeleted', 'error');
         }
         if (is_siteadmin($user->id)) {
-            print_error('useradminodelete', 'error');
+            throw new \moodle_exception('useradminodelete', 'error');
         }
 
         if ($confirm != md5($delete)) {
@@ -115,17 +118,17 @@
         }
     } else if ($acl and confirm_sesskey()) {
         if (!has_capability('moodle/user:update', $sitecontext)) {
-            print_error('nopermissions', 'error', '', 'modify the NMET access control list');
+            throw new \moodle_exception('nopermissions', 'error', '', 'modify the NMET access control list');
         }
         if (!$user = $DB->get_record('user', array('id'=>$acl))) {
-            print_error('nousers', 'error');
+            throw new \moodle_exception('nousers', 'error');
         }
         if (!is_mnet_remote_user($user)) {
-            print_error('usermustbemnet', 'error');
+            throw new \moodle_exception('usermustbemnet', 'error');
         }
         $accessctrl = strtolower(required_param('accessctrl', PARAM_ALPHA));
         if ($accessctrl != 'allow' and $accessctrl != 'deny') {
-            print_error('invalidaccessparameter', 'error');
+            throw new \moodle_exception('invalidaccessparameter', 'error');
         }
         $aclrecord = $DB->get_record('mnet_sso_access_control', array('username'=>$user->username, 'mnet_host_id'=>$user->mnethostid));
         if (empty($aclrecord)) {
@@ -183,13 +186,14 @@
     // These columns are always shown in the users list.
     $requiredcolumns = array('city', 'country', 'lastaccess');
     // Extra columns containing the extra user fields, excluding the required columns (city and country, to be specific).
-    $extracolumns = get_extra_user_fields($context, $requiredcolumns);
-    // Get all user name fields as an array.
-    $allusernamefields = get_all_user_name_fields(false, null, null, null, true);
+    $userfields = \core_user\fields::for_identity($context, true)->excluding(...$requiredcolumns);
+    $extracolumns = $userfields->get_required_fields();
+    // Get all user name fields as an array, but with firstname and lastname first.
+    $allusernamefields = \core_user\fields::get_name_fields(true);
     $columns = array_merge($allusernamefields, $extracolumns, $requiredcolumns);
 
     foreach ($columns as $column) {
-        $string[$column] = get_user_field_name($column);
+        $string[$column] = \core_user\fields::get_display_name($column);
         if ($sort != $column) {
             $columnicon = "";
             if ($column == "lastaccess") {
